==> estateplat-common-1.2.4-20210413.081207-710-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxYbjJrxk.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-银保监会-金融许可证
 */
@Table(name = "xxgx_ybj_jrxk")
public class XxgxYbjJrxk {
    @Id
    private String jrxkid;//金融许可id
    private String cxlx;//查询类型
    private String jgbm;//机构编码
    private String jgdz;//机构地址
    private String lsh;//流水号
    private String ywmc;//业务名称
    private String jgqc;//机构全称
    private String jrxkzid;//金融许可证id
    private String jgjgmc;//监管机构名称
    private Date dyrq;//打印日期
    private String jyfw;//经营范围
    private Date slrq;//设立日期
    private String jgjc;//机构简称
    private String proid;//项目id

    public String getJrxkid() {
        return jrxkid;
    }

    public void setJrxkid(String jrxkid) {
        this.jrxkid = jrxkid;
    }

    public String getCxlx() {
        return cxlx;
    }

    public void setCxlx(String cxlx) {
        this.cxlx = cxlx;
    }

    public String getJgbm() {
        return jgbm;
    }

    public void setJgbm(String jgbm) {
        this.jgbm = jgbm;
    }

    public String getJgdz() {
        return jgdz;
    }

    public void setJgdz(String jgdz) {
        this.jgdz = jgdz;
    }

    public String getLsh() {
        return lsh;
    }

    public void setLsh(String lsh) {
        this.lsh = lsh;
    }

    public String getYwmc() {
        return ywmc;
    }

    public void setYwmc(String ywmc) {
        this.ywmc = ywmc;
    }

    public String getJgqc() {
        return jgqc;
    }

    public void setJgqc(String jgqc) {
        this.jgqc = jgqc;
    }

    public String getJrxkzid() {
        return jrxkzid;
    }

    public void setJrxkzid(String jrxkzid) {
        this.jrxkzid = jrxkzid;
    }

    public String getJgjgmc() {
        return jgjgmc;
    }

    public void setJgjgmc(String jgjgmc) {
        this.jgjgmc = jgjgmc;
    }

    public Date getDyrq() {
        return dyrq;
    }

    public void setDyrq(Date dyrq) {
        this.dyrq = dyrq;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Date getSlrq() {
        return slrq;
    }

    public void setSlrq(Date slrq) {
        this.slrq = slrq;
    }

    public String getJgjc() {
        return jgjc;
    }

    public void setJgjc(String jgjc) {
        this.jgjc = jgjc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}

==> estateplat-common-1.2.4-20210727.094657-831-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxYbjJrxk.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:qijiadong@gtmap.cn">qijiadong</a>
 * @version 1.0, 2020/11/12
 * @description 省级信息共享-银保监会-金融许可证（安徽、江苏）
 */
@Table(name = "xxgx_ybj_jrxk")
public class XxgxYbjJrxk {
    @Id
    private String jrxkid;//金融许可id
    private String cxlx;//查询类型
    private String jgbm;//机构编码
    private String jgdz;//机构地址
    private String lsh;//流水号
    private String ywmc;//业务名称
    private String jgqc;//机构全称
    private String jrxkzid;//金融许可证id
    private String jgjgmc;//监管机构名称
    private Date dyrq;//打印日期
    private String jyfw;//经营范围
    private Date slrq;//设立日期
    private String jgjc;//机构简称
    private String proid;//项目id
    private Date cxsj;//查询时间

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }
    public String getJrxkid() {
        return jrxkid;
    }

    public void setJrxkid(String jrxkid) {
        this.jrxkid = jrxkid;
    }

    public String getCxlx() {
        return cxlx;
    }

    public void setCxlx(String cxlx) {
        this.cxlx = cxlx;
    }

    public String getJgbm() {
        return jgbm;
    }

    public void setJgbm(String jgbm) {
        this.jgbm = jgbm;
    }

    public String getJgdz() {
        return jgdz;
    }

    public void setJgdz(String jgdz) {
        this.jgdz = jgdz;
    }

    public String getLsh() {
        return lsh;
    }

    public void setLsh(String lsh) {
        this.lsh = lsh;
    }

    public String getYwmc() {
        return ywmc;
    }

    public void setYwmc(String ywmc) {
        this.ywmc = ywmc;
    }

    public String getJgqc() {
        return jgqc;
    }

    public void setJgqc(String jgqc) {
        this.jgqc = jgqc;
    }

    public String getJrxkzid() {
        return jrxkzid;
    }

    public void setJrxkzid(String jrxkzid) {
        this.jrxkzid = jrxkzid;
    }

    public String getJgjgmc() {
        return jgjgmc;
    }

    public void setJgjgmc(String jgjgmc) {
        this.jgjgmc = jgjgmc;
    }

    public Date getDyrq() {
        return dyrq;
    }

    public void setDyrq(Date dyrq) {
        this.dyrq = dyrq;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Date getSlrq() {
        return slrq;
    }

    public void setSlrq(Date slrq) {
        this.slrq = slrq;
    }

    public String getJgjc() {
        return jgjc;
    }

    public void setJgjc(String jgjc) {
        this.jgjc = jgjc;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
